<?php defined("SYSPATH") or die("No direct script access.");
/**
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2012 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */
class Admin_Mrtfu_Controller extends Controller {

  public function index() {
    $album_id = Input::instance()->get("album_id");
    print $this->_get_view($album_id);
  }

  public function _get_view($album_id) {
    $album = ORM::factory("item", $album_id);
    $v = new Admin_View("admin.html");
    $v->content = new View("admin_mrtfu_form.html");
    $v->content->mrtfu_form = $this->get_form($album_id);
    $v->content->album_id = $album_id;
    $v->content->album = $album;
    print $v;
  }

  static function get_form($album_id) {
    $album = ORM::factory("item", $album_id);
    $form = new Forge("admin/mrtfu/save?album_id=$album_id", "", "post", array("id" => "g-mrtfu-form"));
    $group1 = $form->group("g_mrtfu_form1")->label(t("Rename the filename of all items in the album to:"));
    $group2 = $form->group("g_mrtfu_form2")->label(t("Rename the title of all items in the album to:"));
    $group3 = $form->group("g_mrtfu_form3")->label(t("Rename the URL of all items in the album to:"));


    $hasphoto = '';
    foreach ($album->viewable()->children() as $child) {
      $title = "title[".$child->id."]";
      $tval = html::chars($child->title);
      $form->hidden($title)->label(t($child->id))->value($tval);
      if($child->is_photo()){ $hasphoto = 1; }
    }
    if(!isset($hasphoto)){
      message::error(t("MRTFU: Nothing to be done... ($hasphoto no photos found in: $album->name)"));
      url::redirect($album->relative_url());	  
    }

    $group1->hidden("JUNK")->label(t("TEST"));
    $group1->checkbox("filename_to_id")
      ->label(t("the item's ID (with existing extension: IE: 12345.jpg)"))
      ->class("g-unique g-button-text")
      ->checked(FALSE);
    $group1->checkbox("filename_to_inc")
      ->label(t("an incremented prefix of:"))
      ->class("g-unique")
      ->checked(FALSE);
    $group1->input("text")
      ->value(t("Example:  'prefix' would generate: prefix1, prefix2, prefix3 ... prefix99"))
      ->class('g-info')
      ->disabled(true);
    $group1->input("filename_prefix")
      ->rules('required|valid_alpha_dash')
      ->error_messages("required", t("You must enter a prefix"))
      ->error_messages("valid_alpha_dash", t("Must only be alpha/numeric/dashes"))
      ->value("prefix");
    $group1->checkbox("filename_donot")
      ->label(t("don't change the filenames"))
      ->class("g-unique")
      ->checked(TRUE);
    
    $group2->checkbox("title_to_id")
      ->label(t("the item's ID"))
      ->class("g-unique2")
      ->checked(FALSE);
    $group2->checkbox("title_to_inc")
      ->label(t("an incremented prefix of:"))
      ->class("g-unique2")
      ->checked(FALSE);
    $group2->input("text")
      ->value(t("Example:  'prefix' would generate: prefix1, prefix2, prefix3 ... prefix99"))
      ->class('g-info')
      ->disabled(true);
    $group2->input("title_prefix")
      ->rules("required")
      ->error_messages("required", t("You must enter a prefix"))
      ->value("prefix");
    $group2->checkbox("title_to_tag")
      ->label(t("the item's tags"))
      ->class("g-unique2")
      ->checked(FALSE);
    $group2->input("tagcnt")
      ->label(t("Number of tags to append"))
      ->rules('required|valid_digit|length[1,1]')
      ->error_messages("required", t("Only allows from 1 to 9 tags"))
      ->error_messages("valid_digit", t("Only allows from 1 to 9 tags"))
      ->error_messages("max_length", t("Only allows from 1 to 9 tags"))
      ->value("3");
    $group2->input("text3")
      ->value(t("Example:  'tags1 | tags2 | tags3'"))
      ->class('g-info')
      ->disabled(true);
    $group2->checkbox("title_donot")
      ->label(t("don't change the titles"))
      ->class("g-unique2")
      ->checked(TRUE);

    $group3->checkbox("url_to_id")
      ->label(t("the item's ID"))
      ->class("g-unique3")
      ->checked(FALSE);
    $group3->checkbox("url_to_inc")
      ->label(t("an incremented prefix of:"))
      ->class("g-unique3")
      ->checked(FALSE);
    $group3->input("text")
      ->value(t("Example:  'prefix' would generate: prefix1, prefix2, prefix3 ... prefix99"))
      ->class('g-info')
      ->disabled(true);
    $group3->input("url_prefix")
      ->rules('required|valid_alpha_dash')
      ->error_messages("required", t("You must enter a prefix"))
      ->error_messages("valid_alpha_dash", t("Must only be alpha/numeric/dashes"))
      ->value("prefix");
    $group3->checkbox("url_donot")
      ->label(t("don't change the URLs"))
      ->class("g-unique3")
      ->checked(TRUE);


    $form->submit("submit")->value(t("Do It!"))->class("submit ui-state-default ui-corner-all");
    return $form;
  }

  public function save() {
    $album_id = Input::instance()->get("album_id");
    $album = ORM::factory("item", $album_id);
    $form = $this->get_form($album_id);
    $valid = $form->validate();
    
    if($valid) {
      $fn2id = Input::instance()->post("filename_to_id");
      $fn2inc = Input::instance()->post("filename_to_inc");
      $fnprefix = Input::instance()->post("filename_prefix");
      $fnprefix = preg_replace("/\s+/","",$fnprefix);
      $fndnc = Input::instance()->post("filename_donot");

      $t2id = Input::instance()->post("title_to_id");
      $t2inc = Input::instance()->post("title_to_inc");
      $tprefix = Input::instance()->post("title_prefix");
      $t2tag = Input::instance()->post("title_to_tag");
      $tdnc = Input::instance()->post("title_donot");
      $tagcnt = Input::instance()->post("tagcnt");

      $url2id = Input::instance()->post("url_to_id");
      $url2inc = Input::instance()->post("url_to_inc");
      $urlprefix = Input::instance()->post("url_prefix");
      $urlprefix = preg_replace("/\s+/","",$urlprefix);
      $urldnc = Input::instance()->post("url_donot");

      $titles = Input::instance()->post("title");
      $cnt=1;
      $yestask = 0;
      foreach(array_keys($titles) as $id) {
	if($fndnc && $tdnc && $urldnc){
	  message::error(t("MRTFU: Nothing to be done... You did not choose any options that required action."));
          url::redirect($album->relative_url());	  
	}
	$item = ORM::factory("item", $id);
	$record = ORM::factory("mrtfu_item");
	if($item->loaded()) {
	  if($item->is_photo()){

// DOIT: $doit = failsafe... 
$doit = 1;
//

// TAGS HERE
	    if($t2tag){
	      $tagline = "";
	      $hastags = "";
	      $inrec = "";
	      foreach (ORM::factory("items_tag")
		       ->where("item_id", "=", $item->id)->find_all($tagcnt) as $tags){
		if($tags->loaded()){
		  $tagname = ORM::factory("tag")
		    ->where("id", "=", $tags->tag_id)
		    ->find();
		  if($tagline){
		    $tagline .= " | ".$tagname->name;
		  } else {
		    $tagline = $tagname->name;
		  }
		  $hastags=1;
		}
              }
	      if($hastags){
		$record->item_title = $tagline;
		$inrec = 1;
#		message::error(t("TAGLINE: $tagline"));
#		url::redirect($album->relative_url());	  
	      }
	    }
// END TAGS

	    $fn_ext = pathinfo($item->name, PATHINFO_EXTENSION);

	    if($doit){
	      $record->item_id = $item->id;
	      if($fn2id){
		if($fn_ext){
		  $record->item_name = $item->id.".".$fn_ext;
		} else {
		  $record->item_name = $item->id;
		}
		$inrec = 1;
	      }
	      if($fn2inc){
		if($fn_ext){
		  $record->item_name = $fnprefix.$cnt.".".$fn_ext;
		} else {
		  $record->item_name = $fnprefix.$cnt;
		}
		$inrec = 1;
	      }
	      if($t2id){
		$record->item_title = $item->id;
		$inrec = 1;
	      }
	      if($t2inc){
		$record->item_title = $tprefix.$cnt;
		$inrec = 1;
	      }
	      if($url2id){
		$record->item_url = $item->id;
		$inrec = 1;
	      }
	      if($url2inc){
		$record->item_url = $urlprefix.$cnt;
		$inrec = 1;
	      }
	      if($inrec){
		$record->save();
		$cnt++;
		$yestask = 1;
		$inrec = "";
	      }
	    }
	  }
	}
      }
      if($yestask){
	site_status::warning(
	  t('Your MRTFU task has been created.  <a href="%url">Click to run it!</a>',
	    array("url" => html::mark_clean(url::site("admin/maintenance")))),
	"mrtfu_task_created");
      } else {
	  message::error(t("MRTFU: Nothing to be done..."));
      }
      url::redirect($album->relative_url());
    } else {
      print $this->_get_view($album_id);
    }
  }
}
