<?php defined("SYSPATH") or die("No direct script access.");
/**
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2012 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */

class Mrtfu_task_Core {

  static function available_tasks() {

// Delete mrtfus that are done already...
    db::build()
      ->delete("mrtfu_items")
      ->where("task_done", "=", "1")
      ->execute();

    list ($remaining, $total, $percent) = mrtfu::stats();
    return array(Task_Definition::factory()
                 ->callback("mrtfu_task::do_mrtfu")
                 ->name(t("Complete the MRTFU task"))
                 ->description("You have $remaining items to complete in the MRTFU task")

                 ->description($remaining
                               ? t2("1 item needs to be mrtfu'd",
                                    "%count (%percent%) items need to be mrtfu'd",
                                    $remaining, array("percent" => (100 - $percent)))
                               : t("No mrtfu items outstanding"))

		 ->severity($remaining ? log::WARNING : log::SUCCESS));
  }

  static function do_mrtfu($task) {
    $completed = $task->get("completed", 0);
    $start = microtime(true);

    foreach (ORM::factory("mrtfu_item")
	->where("task_done", "=", "0")
	->find_all(100) as $item) {

      if(!isset($start)) {
	$start = microtime(true);
      }

      mrtfu::do_the_mrtfu($item);

      $completed++;

      if (microtime(true) - $start > .75) {
	break;
      }
    }

    list($remaining, $total, $percent) = mrtfu::stats();
    $task->set("completed", $completed);
    if ($remaining == 0 || !($remaining + $completed)) {
      $task->done = true;
      $task->state = "success";
      site_status::clear("mrtfu_task_created");
      $task->percent_complete = 100;
    } else {
      $task->percent_complete = round(100 * $completed / ($remaining + $completed));
    }
    $task->status = t2("1 record updated, task is %percent% complete",
		       "%count records updated, task is %percent% complete",
			$completed, array("percent" => $percent));
  }
}
